summaryrefslogtreecommitdiffstats
path: root/libk3b/plugin/k3bpluginfactory.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-27 19:21:21 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-27 19:21:21 +0000
commitd8cc8bdfa7fa624a526d5aa1626974e1444cb799 (patch)
treef295f1c545b319963d5357af79fe08991d8141d9 /libk3b/plugin/k3bpluginfactory.h
parent2a39a080579fb52a2599c02b2939795385b89093 (diff)
downloadk3b-d8cc8bdfa7fa624a526d5aa1626974e1444cb799.tar.gz
k3b-d8cc8bdfa7fa624a526d5aa1626974e1444cb799.zip
TQt4 port k3b
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/k3b@1233803 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libk3b/plugin/k3bpluginfactory.h')
-rw-r--r--libk3b/plugin/k3bpluginfactory.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/libk3b/plugin/k3bpluginfactory.h b/libk3b/plugin/k3bpluginfactory.h
index 6dbc6cb..463703f 100644
--- a/libk3b/plugin/k3bpluginfactory.h
+++ b/libk3b/plugin/k3bpluginfactory.h
@@ -23,7 +23,7 @@
#include <klocale.h>
/**
* Template based on KGenericFactory. This is just here to avoid using the QStringList args parameter
* in every plugin's constructor.
*
* Use this as follows:
@@ -64,14 +64,14 @@ class K3bPluginFactory : public KLibFactory
}
}
- virtual QObject* createObject( QObject *parent, const char *name,
- const char*, const QStringList& ) {
+ virtual TQObject* createObject( TQObject *tqparent, const char *name,
+ const char*, const TQStringList& ) {
initializeMessageCatalogue();
- return new T( parent, name );
+ return new T( tqparent, name );
}
private:
- QCString m_instanceName;
+ TQCString m_instanceName;
bool m_catalogueInitialized;
static KInstance* s_instance;
@@ -23,7 +23,7 @@
#include <klocale.h>
/**
- * Template based on KGenericFactory. This is just here to avoid using the QStringList args parameter
+ * Template based on KGenericFactory. This is just here to avoid using the TQStringList args parameter
* in every plugin's constructor.
*